==> piwigo-11.5.0.zip: piwigo/plugins/TakeATour/language/sv_SE/tour_first_contact.lang.php <==
<?php
$lang['first_contact_title10'] = '';
$lang['first_contact_title12'] = '';
$lang['first_contact_title13'] = '';
$lang['first_contact_title14'] = '';
$lang['first_contact_title16'] = '';
$lang['first_contact_title17'] = '';
$lang['first_contact_title2'] = '';
$lang['first_contact_title23'] = '';
$lang['first_contact_title30'] = '';
$lang['first_contact_title31'] = '';
$lang['first_contact_title32'] = '';
$lang['first_contact_title40'] = '';
$lang['first_contact_title41'] = '';
$lang['first_contact_title5'] = '';
$lang['first_contact_title6'] = '';
$lang['first_contact_title7'] = '';
$lang['first_contact_title8'] = '';
$lang['first_contact_stp1'] = 'Hej! Jag kommer att vara din guide när du upptäcker Piwigo. Följ mina instruktioner och klicka på Nästa (eller använd tangentbordets piltangenter) för att navigera. Om du går till en annan administrationssida, kommer du att bli omdirigerad till den aktuella sidan i guiden. Om du fastnar och inte kan avsluta guiden, går du till <em>Insticksmoduler »Ta en tur</ em> så avslutas guideturen.<br>Nu börjar vi med att lägga till bilder!';
$lang['first_contact_stp38'] = 'Tillägg är ett enkelt sätt att hantera din Piwigo med. De kan göra nästan allt du kan tänka dig, från små text-tillägg till hela presentationer, som tex Gemenskaps-tillägget som tillåter icke-administratörer att ladda upp utan att gå in i administrations-delen.';
$lang['first_contact_stp37'] = 'För att installera nya teman, kan man ladda ner dem direkt från fliken "Lägg till tema". Bara de teman som är kompatibla med din Piwigo-version visas.<br><br>Låt oss undersöka tillägen nu! Klicka på <em>Tillägg » Hantera</em>';
$lang['first_contact_stp34'] = 'Att välja ett tema är det första steget för att anpassa din Piwigo. Installerade teman listas här.
<br>Mer än ett tema kan aktiveras: användare kan ändra sina teman genom att välja ett av de aktiverade temorna här, om valet "Tillåt användar-anpassning" är förbockat på Inställningssidan.';
$lang['first_contact_stp33'] = 'Bara ett sista ord om inställningarna, \'Gäst\'-inställningarna är för att ställa in behörigheter för oregistrerade besökare. Varje gång Piwigo refererar till en "gäst", betyder det en oregistrerad besökare.
<br>Nu fortsätter vi med konfigurationen: klicka på <em>Inställningar » Teman</em> eller klicka på Nästa.';
$lang['first_contact_stp32'] = 'Spara ändringarna nu';
$lang['first_contact_stp31'] = 'Sen har vi banneren, som kommer att synas högst upp på alla sidor. Som du kan se, är HTML-taggar tillåtna här. Du kan också använda %gallery_title%-taggen för att visa titeln du just skrev in ovan.';
$lang['first_contact_title9'] = 'Batch Managern';
$lang['first_contact_title43'] = 'Det har varit fantastiskt';
$lang['first_contact_title4'] = 'Låt oss lägga till ett foto!';
$lang['first_contact_title38'] = 'Tillägg';
$lang['first_contact_title39'] = 'Tillägg';
$lang['first_contact_title35'] = 'Teman';
$lang['first_contact_title37'] = 'Teman';
$lang['first_contact_title34'] = 'Teman';
$lang['first_contact_title33'] = 'Gäst-inställningar';
$lang['first_contact_title3'] = 'Lägg till foto-sidan';
$lang['first_contact_title29'] = '<em>Konfiguration » Inställningar » Generellt</em>';
$lang['first_contact_title28'] = 'Konfiguration';
$lang['first_contact_title22'] = 'Editeringssida för album';
$lang['first_contact_title21'] = 'Andra flikar';
$lang['first_contact_title20'] = 'Hantera album';
$lang['first_contact_title19'] = 'Hantera album';
$lang['first_contact_title18'] = 'Hantera album';
$lang['first_contact_title15'] = 'Editeringssidan för ett foto';
$lang['first_contact_title11'] = 'Hur man redigerar ett foto';
$lang['first_contact_title1'] = 'Välkommen till ditt Piwigo-galleri';
$lang['first_contact_stp8'] = 'Låt oss redigera dem! Klicka på länken';
$lang['first_contact_stp6'] = 'Du ser att foton listas. När du är klar, klicka på knappen Börja Uppladdning';
$lang['first_contact_stp5'] = 'Klicka sen på knappen för att välja de foton som ska laddas upp, eller dra och släpp dina filer.';
$lang['first_contact_stp4'] = 'Välj ett album först; skapa ett om det inte finns något än.';
$lang['first_contact_stp35'] = 'Sätt ditt favorittema som standardtema.';
$lang['first_contact_stp19'] = 'Här listas "rot"-albumen. Om du ser ett album med en streckad bakgrund, betyder det att det är ett fysiskt album från en FTP-synkronisering. Fysiska album kan inte flyttas eller tas bort härifrån. De andra albumen kallas virtuella album.';
$lang['first_contact_stp3'] = 'Den här första fliken används för att lägga till bilder direkt från webbläsaren. De andra flikarna är till för andra sätt att ladda upp bilder';
$lang['first_contact_stp28'] = 'Nu ska vi titta på de val som finns för att få Piwigo att bete sig precis som vi vill. Klicka på Inställningar->Alternativ eller klicka på Nästa.';
$lang['first_contact_stp23'] = 'Att låsa ett album, innebär att bara en administratör kommer att kunna se albumet: detta är användbart när man förbereder ett album för publicering';
$lang['first_contact_stp21'] = 'Nästa flik är en sida där du kan flytta omkring alla virtuella album.<br>Permallink-fliken är satt till en specifik URL för albumet.<br>Låt oss nu redigera ett album: klicka på Redigera ett album';
$lang['first_contact_stp20'] = 'När din muspekare svävar över ett album, syns länkar och information. När du drar och släpper ett album - ett rundat block -, kommer du att ändra dess placering och sedan kan du spara eller ångra din manuella sorteringsinställning.
';
$lang['first_contact_stp19_b'] = 'Här listas "rot"-albumen.';
$lang['first_contact_stp17'] = 'Här kan man sätta en miniatyrbild för ett eller flera album.  Bilden behöver inte vara associerat med albumet på något sätt för att sättas som miniatyrbild. Om bilden är associerat med albumet, är det ännu enklare att sätta det som album-miniatyrbild från den publika sidan. (Tips: Använd tillägget Admin Tools för ännu enklare hantering).';
$lang['first_contact_stp16'] = '…i vilka album ligger bilden.<br><br>Så här kan du lägga till eller ta bort bilder från album. Länken är virtuell, inga bilder kommer någonsin att flyttas fysiskt.';
$lang['first_contact_stp14'] = 'Nu kommer vi att se bildens <b>redigerasida</b>. Sidan nås härifrån men också från den publika fotosidan när man är inloggad som administrator.<br><br>Hovra över miniatyrbilden och klicka på Redigera.';
$lang['first_contact_stp13'] = 'Du kan redigera beskrivningar och annat från batchhanterarens enkel-läge, men just nu håller vi oss kvar i det globala läget';
$lang['first_contact_stp12'] = 'för att sedan redigera dem med en handling';
$lang['first_contact_stp10'] = 'Här är länken till din uppsamlingskorg: det är ett verktyg för administratörer att enkelt välja bilder när de söker igenom den offentliga delen för att sedan redigera bilderna i batchhanteraren.<br><br>Du kan lägga till bilder i korgen från den publika bildsidan när du är inloggad som en administratör, eller genom att använda åtgärden "Lägg till i korgen" på Batchhanteraren.
<br>Du kan lägga till foton i caddien från den publika fotosidan när du är inloggad som en admin, eller genom åtgärden "Lägg till i caddien" i Batch Managern.';
$lang['first_contact_stp30'] = 'Låt oss börja med att ändra titeln';
$lang['first_contact_stp29'] = 'Här, på den första sidan, ställer du in de nödvändiga och grundläggande inställningarna på ditt galleri';
$lang['first_contact_stp22'] = 'Precis som med en bild, kan man redigera ett albums egenskaper';
$lang['first_contact_stp2'] = 'Här är länken. Klicka på den eller klicka Nästa för att fortsätta';
$lang['first_contact_stp18'] = 'Låt oss nu se hur man hanterar album. Klicka <em>På album » Hantera</em> eller klicka på Nästa
';
$lang['first_contact_stp15'] = 'På den här sidan kan du redigera alla egenskaper hos en bild, till exempel…';
$lang['first_contact_stp11'] = 'Härifrån kan du välja en eller flera bilder';
$lang['first_contact_stp39'] = 'På den första sidan, listas samtliga installerade plugin (insticksprogram).<br><br>Upptill listas de aktiverade plugin som för närvarande är igång.<br><br>Längst ner, listas plugin som är installerade i /plugins mappen, men inaktiverade.<br><br>Radering av ett plugin innebär att alla spår av insticksprogrammet kommer att tas bort (filer, tillval, etc.). För de flesta plugin, kommer data som registrerats av insticksprogrammet att behållas vid inaktivering.';
$lang['first_contact_stp40'] = 'Jag är här! inaktivera mej inte nu, men du kan se att du kan Inaktivera Eller Återställa ett aktiverat plugin.';
$lang['first_contact_stp41'] = 'På sista fliken kan di se samtliga tillgängliga plugin för din Piwigo-version. Hundratalet plugin finns här!';
$lang['first_contact_stp43'] = 'Den här turen var ganska lång, men vi har bara sett en liten del av hur kraftfull Piwigo är. Allt har ett slut, denna översikt är klar.<br><br>Du kan undersöka funktionerna djupare i Piwigo genom att ta en annan tur eller läsa vår dokumentation, på webbplatsen piwigo.org.<br><br>Glöm inte att det även finns en Hjälp-länk i det övre högra hörnet på administrationssidan <p style="text-align:center">Njut av din Piwigo!</p>';
$lang['first_contact_stp7'] = 'Här är en summering av dina uppladdade bilder. Som du ser har Piwigo skapat miniatyrbilderna';

==> piwigo-16.0.0.zip: piwigo/plugins/TakeATour/language/sv_SE/tour_first_contact.lang.php <==
<?php
$lang['first_contact_title10'] = '';
$lang['first_contact_title12'] = '';
$lang['first_contact_title13'] = '';
$lang['first_contact_title14'] = '';
$lang['first_contact_title16'] = '';
$lang['first_contact_title17'] = '';
$lang['first_contact_title2'] = '';
$lang['first_contact_title23'] = '';
$lang['first_contact_title30'] = '';
$lang['first_contact_title31'] = '';
$lang['first_contact_title32'] = '';
$lang['first_contact_title40'] = '';
$lang['first_contact_title41'] = '';
$lang['first_contact_title5'] = '';
$lang['first_contact_title6'] = '';
$lang['first_contact_title7'] = '';
$lang['first_contact_title8'] = '';
$lang['first_contact_stp1'] = 'Hej! Jag kommer att vara din guide när du upptäcker Piwigo. Följ mina instruktioner och klicka på Nästa (eller använd tangentbordets piltangenter) för att navigera. Om du går till en annan administrationssida, kommer du att bli omdirigerad till den aktuella sidan i guiden. Om du fastnar och inte kan avsluta guiden, går du till <em>Insticksmoduler »Ta en tur</ em> så avslutas guideturen.<br>Nu börjar vi med att lägga till bilder!';
$lang['first_contact_stp38'] = 'Tillägg är ett enkelt sätt att hantera din Piwigo med. De kan göra nästan allt du kan tänka dig, från små text-tillägg till hela presentationer, som tex Gemenskaps-tillägget som tillåter icke-administratörer att ladda upp utan att gå in i administrations-delen.';
$lang['first_contact_stp37'] = 'För att installera nya teman, kan man ladda ner dem direkt från fliken "Lägg till tema". Bara de teman som är kompatibla med din Piwigo-version visas.<br><br>Låt oss undersöka tillägen nu! Klicka på <em>Tillägg » Hantera</em>';
$lang['first_contact_stp34'] = 'Att välja ett tema är det första steget för att anpassa din Piwigo. Installerade teman listas här.
<br>Mer än ett tema kan aktiveras: användare kan ändra sina teman genom att välja ett av de aktiverade temorna här, om valet "Tillåt användar-anpassning" är förbockat på Inställningssidan.';
$lang['first_contact_stp33'] = 'Bara ett sista ord om inställningarna, \'Gäst\'-inställningarna är för att ställa in behörigheter för oregistrerade besökare. Varje gång Piwigo refererar till en "gäst", betyder det en oregistrerad besökare.
<br>Nu fortsätter vi med konfigurationen: klicka på <em>Inställningar » Teman</em> eller klicka på Nästa.';
$lang['first_contact_stp32'] = 'Spara ändringarna nu';
$lang['first_contact_stp31'] = 'Sen har vi banneren, som kommer att synas högst upp på alla sidor. Som du kan se, är HTML-taggar tillåtna här. Du kan också använda %gallery_title%-taggen för att visa titeln du just skrev in ovan.';
$lang['first_contact_title9'] = 'Batch Managern';
$lang['first_contact_title43'] = 'Det har varit fantastiskt';
$lang['first_contact_title4'] = 'Låt oss lägga till ett foto!';
$lang['first_contact_title38'] = 'Tillägg';
$lang['first_contact_title39'] = 'Tillägg';
$lang['first_contact_title35'] = 'Teman';
$lang['first_contact_title37'] = 'Teman';
$lang['first_contact_title34'] = 'Teman';
$lang['first_contact_title33'] = 'Gäst-inställningar';
$lang['first_contact_title3'] = 'Lägg till foto-sidan';
$lang['first_contact_title29'] = '<em>Konfiguration » Inställningar » Generellt</em>';
$lang['first_contact_title28'] = 'Konfiguration';
$lang['first_contact_title22'] = 'Editeringssida för album';
$lang['first_contact_title21'] = 'Andra flikar';
$lang['first_contact_title20'] = 'Hantera album';
$lang['first_contact_title19'] = 'Hantera album';
$lang['first_contact_title18'] = 'Hantera album';
$lang['first_contact_title15'] = 'Editeringssidan för ett foto';
$lang['first_contact_title11'] = 'Hur man redigerar ett foto';
$lang['first_contact_title1'] = 'Välkommen till ditt Piwigo-galleri';
$lang['first_contact_stp8'] = 'Låt oss redigera dem! Klicka på länken';
$lang['first_contact_stp6'] = 'Du ser att foton listas. När du är klar, klicka på knappen Börja Uppladdning';
$lang['first_contact_stp5'] = 'Klicka sen på knappen för att välja de foton som ska laddas upp, eller dra och släpp dina filer.';
$lang['first_contact_stp4'] = 'Välj ett album först; skapa ett om det inte finns något än.';
$lang['first_contact_stp35'] = 'Sätt ditt favorittema som standardtema.';
$lang['first_contact_stp19'] = 'Här listas "rot"-albumen. Om du ser ett album med en streckad bakgrund, betyder det att det är ett fysiskt album från en FTP-synkronisering. Fysiska album kan inte flyttas eller tas bort härifrån. De andra albumen kallas virtuella album.';
$lang['first_contact_stp3'] = 'Den här första fliken används för att lägga till bilder direkt från webbläsaren. De andra flikarna är till för andra sätt att ladda upp bilder';
$lang['first_contact_stp28'] = 'Nu ska vi titta på de val som finns för att få Piwigo att bete sig precis som vi vill. Klicka på Inställningar->Alternativ eller klicka på Nästa.';
$lang['first_contact_stp23'] = 'Att låsa ett album, innebär att bara en administratör kommer att kunna se albumet: detta är användbart när man förbereder ett album för publicering';
$lang['first_contact_stp21'] = 'Nästa flik är en sida där du kan flytta omkring alla virtuella album.<br>Permallink-fliken är satt till en specifik URL för albumet.<br>Låt oss nu redigera ett album: klicka på Redigera ett album';
$lang['first_contact_stp20'] = 'När din muspekare svävar över ett album, syns länkar och information. När du drar och släpper ett album - ett rundat block -, kommer du att ändra dess placering och sedan kan du spara eller ångra din manuella sorteringsinställning.
';
$lang['first_contact_stp19_b'] = 'Här listas "rot"-albumen.';
$lang['first_contact_stp17'] = 'Här kan man sätta en miniatyrbild för ett eller flera album.  Bilden behöver inte vara associerat med albumet på något sätt för att sättas som miniatyrbild. Om bilden är associerat med albumet, är det ännu enklare att sätta det som album-miniatyrbild från den publika sidan. (Tips: Använd tillägget Admin Tools för ännu enklare hantering).';
$lang['first_contact_stp16'] = '…i vilka album ligger bilden.<br><br>Så här kan du lägga till eller ta bort bilder från album. Länken är virtuell, inga bilder kommer någonsin att flyttas fysiskt.';
$lang['first_contact_stp14'] = 'Nu kommer vi att se bildens <b>redigerasida</b>. Sidan nås härifrån men också från den publika fotosidan när man är inloggad som administrator.<br><br>Hovra över miniatyrbilden och klicka på Redigera.';
$lang['first_contact_stp13'] = 'Du kan redigera beskrivningar och annat från batchhanterarens enkel-läge, men just nu håller vi oss kvar i det globala läget';
$lang['first_contact_stp12'] = 'för att sedan redigera dem med en handling';
$lang['first_contact_stp10'] = 'Här är länken till din uppsamlingskorg: det är ett verktyg för administratörer att enkelt välja bilder när de söker igenom den offentliga delen för att sedan redigera bilderna i batchhanteraren.<br><br>Du kan lägga till bilder i korgen från den publika bildsidan när du är inloggad som en administratör, eller genom att använda åtgärden "Lägg till i korgen" på Batchhanteraren.
<br>Du kan lägga till foton i caddien från den publika fotosidan när du är inloggad som en admin, eller genom åtgärden "Lägg till i caddien" i Batch Managern.';
$lang['first_contact_stp30'] = 'Låt oss börja med att ändra titeln';
$lang['first_contact_stp29'] = 'Här, på den första sidan, ställer du in de nödvändiga och grundläggande inställningarna på ditt galleri';
$lang['first_contact_stp22'] = 'Precis som med en bild, kan man redigera ett albums egenskaper';
$lang['first_contact_stp2'] = 'Här är länken. Klicka på den eller klicka Nästa för att fortsätta';
$lang['first_contact_stp18'] = 'Låt oss nu se hur man hanterar album. Klicka <em>På album » Hantera</em> eller klicka på Nästa
';
$lang['first_contact_stp15'] = 'På den här sidan kan du redigera alla egenskaper hos en bild, till exempel…';
$lang['first_contact_stp11'] = 'Härifrån kan du välja en eller flera bilder';
$lang['first_contact_stp39'] = 'På den första sidan, listas samtliga installerade plugin (insticksprogram).<br><br>Upptill listas de aktiverade plugin som för närvarande är igång.<br><br>Längst ner, listas plugin som är installerade i /plugins mappen, men inaktiverade.<br><br>Radering av ett plugin innebär att alla spår av insticksprogrammet kommer att tas bort (filer, tillval, etc.). För de flesta plugin, kommer data som registrerats av insticksprogrammet att behållas vid inaktivering.';
$lang['first_contact_stp40'] = 'Jag är här! inaktivera mej inte nu, men du kan se att du kan Inaktivera Eller Återställa ett aktiverat plugin.';
$lang['first_contact_stp41'] = 'På sista fliken kan di se samtliga tillgängliga plugin för din Piwigo-version. Hundratalet plugin finns här!';
$lang['first_contact_stp43'] = 'Den här turen var ganska lång, men vi har bara sett en liten del av hur kraftfull Piwigo är. Allt har ett slut, denna översikt är klar.<br><br>Du kan undersöka funktionerna djupare i Piwigo genom att ta en annan tur eller läsa vår dokumentation, på webbplatsen piwigo.org.<br><br>Glöm inte att det även finns en Hjälp-länk i det övre högra hörnet på administrationssidan <p style="text-align:center">Njut av din Piwigo!</p>';
$lang['first_contact_stp7'] = 'Här är en summering av dina uppladdade bilder. Som du ser har Piwigo skapat miniatyrbilderna';
$lang['first_contact_stp9'] = 'Du är nu i batch hanteraren, där du kan batchredigera flera foton.<br><br>Här är förfiltret redan satt till "Caddie" eftersom vi kommer från uppladdningssidan.';
